/**
 * Customizer preview scripts.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );

	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Footer copyright name.
	wp.customize( 'copy_name', function( value ) {
		value.bind( function( to ) {
			$( '#footer-copy-name' ).text( to );
		} );
	} );

	// Footer credits.
	wp.customize( 'powered_by_wp', function( value ) {
		value.bind( function( to ) {
			$( '.wordpress-credit' ).toggle( to );
		} );
	} );
	wp.customize( 'theme_meta', function( value ) {
		value.bind( function( to ) {
			$( '.theme-credit' ).toggle( to );
		} );
	} );

	// Linework script settings. For each option, reset the animation on change for immediate feedback.
	wp.customize( 'lw_animate', function( value ) {
		value.bind( function( to ) {
			window.lw.settings.animate = to;
			window.lw.init();
		} );
	} );

	wp.customize( 'lw_initial', function( value ) {
		value.bind( function( to ) {
			window.lw.settings.initial = to;
			window.lw.init();
		} );
	} );

	wp.customize( 'linework_color', function( value ) {
		value.bind( function( to ) {
			window.lw.settings.color = to;
			window.lw.init();
			// Update custom color CSS
			var style = $( '#linework-colors' ),
			    color = style.data( 'linework_color' ),
			    css = style.html();

			css = css.split( color ).join( to ); // css.replaceAll.
			$( '#linework-colors' ).html( css )
			                       .data( 'linework_color', to );
		} );
	} );

	wp.customize( 'lw_background_color', function( value ) {
		value.bind( function( to, from ) {
			// Update custom color CSS
			var style = $( '#linework-colors' ),
			    color = style.data( 'background_color' ),
			    css = style.html();

			css = css.split( color ).join( to ); // css.replaceAll.
			$( '#linework-colors' ).html( css )
			                       .data( 'background_color', to );
		} );
	} );

	// Toggle a body class to enable the page fade-in animation (triggers the animation when added).
	wp.customize( 'lw_animate_page', function( value ) {
		value.bind( function( to ) {
			$( 'body' ).toggleClass( 'fade-in-page', to );
		} );
	} );
} )( jQuery );
